
# q-expansion of newform 825.6.a.p, downloaded from the LMFDB on 05 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 825
weight = 6
poly_data = [-33248, 149572, -118840, -15851, 9055, 272, -176, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0], 1], [[-44, 1, 1, 0, 0, 0, 0, 0], 1], [[-44, -70, 2, 1, 0, 0, 0, 0], 1], [[55536, -36334, -7927, 1600, 164, -14, -1, 0], 160], [[99104, -85572, -13084, 7407, 176, -160, 0, 1], 320], [[89856, -146720, -15018, 10287, 344, -188, -2, 1], 320], [[-129568, 314100, 6664, -24861, 208, 504, -4, -3], 320]]

hecke_ring_character_values = None
aps_data = [[-1, -1, 0, 0, 0, 0, 0, 0], [9, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0], [9, -3, -1, 0, 0, 0, -1, 0], [-121, 0, 0, 0, 0, 0, 0, 0], [-52, 42, -3, 2, 0, 1, -1, 1], [-35, -6, -5, -1, -1, -1, 10, 0], [-125, 34, 2, 3, -3, 4, -7, -3], [-739, -1, -6, 7, 3, -9, 1, -6], [126, 101, -15, 5, 7, -22, -6, -1], [-598, 44, -37, -22, 0, 9, 21, 9], [2049, 426, 141, 20, 10, 41, 45, 1], [-1613, -116, -93, 15, 3, 21, 58, -26], [-2806, -56, -121, 0, -38, -35, -5, 21], [-1013, 490, 325, -88, -2, -23, 1, 17], [-872, 438, 128, 60, 48, 106, -4, -38], [-9673, -620, -21, -68, 22, 77, 147, -27], [1624, 303, -796, 17, -23, -115, 9, 64], [-2952, 1531, 472, -199, 1, -203, -67, 40], [-2527, -1199, -362, -163, 65, 73, -165, -58], [-8060, -720, -202, -242, 22, 122, -68, -8], [-2535, -3048, 475, 175, -37, -111, 198, 126], [-12368, 129, -339, 179, 49, 86, -184, -165], [-2630, -7661, 929, -235, 11, 16, 102, 131], [-18577, 4322, 452, -30, 18, 298, 446, -208], [-5653, 3331, -644, 58, 128, -515, -226, -43], [20702, -637, 525, -433, -191, -304, 128, 235], [-43108, 6155, -1309, -557, -79, -386, -138, 107], [-29896, -3250, 1141, 644, 254, 477, -359, -349], [22936, 2632, 574, 454, 118, -558, 36, 148], [-36853, 10680, 1805, 153, -211, 215, 962, -158], [-11372, -5867, 3925, -601, -395, 266, -124, 43], [-56504, 31957, -293, 323, 133, 396, -354, -23], [-43278, -7517, 4343, -565, -511, -158, 626, 623], [-62991, -16092, 1025, 1135, -169, -89, -436, -60], [-96308, 22097, -1222, 13, -427, -67, -2645, -160], [-78498, 17843, 2028, -249, -373, -527, -577, -198], [137404, -477, 5350, 373, -39, 215, -273, -1202], [-47424, 18402, -3002, 468, 844, 1408, -814, -448], [85435, -36387, -2810, -1132, 86, 617, 1498, 539], [-163673, -700, 1241, -152, -170, 807, 4421, 59], [-53921, 4435, 2447, -647, 903, 1230, -352, -311], [-123159, 20449, -3754, 1925, -503, -735, -1101, 622], [192820, 9579, -1040, -677, -825, 613, 2855, 1554], [-59657, 29879, 5436, -754, -700, 1145, 2842, 1013], [-142232, -488, 219, 312, 298, -2907, -293, -1029], [-261288, 13089, -4494, -987, -35, 2133, 707, 1984], [400440, -20359, 5614, 2515, 1047, 457, -883, -498], [-252740, -937, -5611, 1, 223, -2232, -3834, 279], [-51329, -35965, 7079, -2723, -541, 1166, 1700, 3033], [-174861, -54464, -19167, 343, -1105, -2669, -2024, 520], [-272600, -16346, 9588, -438, 738, -2386, 2238, -696], [-344522, 50865, -6830, 5039, 483, -1843, 733, -894], [-420516, -65514, 18252, 1010, 1074, 2342, -4530, -816], [-614264, -26239, 5683, -587, -1965, -168, 2624, -1085], [-65334, -108118, -4530, -870, 814, 4368, -1184, 1786], [-139090, 84734, -790, 4582, -502, -2816, -4856, 2486], [-702363, -1648, -8893, -25, -941, -879, -306, -634], [120516, -81379, 1116, 1983, -241, -6441, -3257, 1828], [-278797, -147888, -12955, -237, -1325, 4167, 1992, 1316], [-82045, -83243, -9037, -1780, -884, -4428, -5253, -3188], [-372763, -90836, -14643, 5619, 1195, 643, -2636, -3308], [-404312, -145551, 10514, -1771, -3107, -763, 6531, -1088], [-216028, -107339, 8507, 4615, 1953, -1920, -10762, -1317], [115085, 41815, 15015, 11571, 1289, -1882, 5114, 635], [-660792, -36882, 16272, 4568, 3900, 7538, 1192, -4922], [-619292, 138986, -17198, 346, 1054, -1772, 10804, -3042], [-326488, -269569, -6410, -1211, -487, 1963, 6991, -1030], [-659464, -58088, 12676, -3718, -538, 2580, -14650, 4946], [-272322, 149955, 10147, 343, 1613, -678, -5682, 2737], [-173570, -126181, -6227, 11777, 711, 1052, -4114, -1293], [-361310, -68950, 10184, -8056, -5924, -6618, 7296, 1610], [158358, -172582, -2289, -8132, 1610, 3159, -5837, 2197], [-958146, -244045, -22138, -15925, 2035, 6463, -5395, 2384], [-1131686, 99989, -5872, -5191, -7891, -2901, -1059, -1494], [207396, -117113, 77541, -1303, -817, 8516, -5046, 345], [-205422, -53072, 648, -11450, -790, 4336, -11850, 1022], [468230, 80599, 472, 12127, 7395, -4479, 18563, -5166], [-483666, -134197, 23405, -10775, -6153, 8828, 23158, -2397], [-1051904, -1435, 6336, 6775, 3543, -7629, 13275, -4984], [943785, -163556, -11479, -1128, 9646, 7375, -14667, 3067], [860417, 236172, 52351, -9606, 1204, 4053, -9483, -1225], [-894790, 87284, -10888, 3230, 626, -7212, -4618, 7294], [352856, -127798, -45249, -2606, 364, -6557, 10781, 3665], [-467179, -97407, 10175, 1440, 5720, -7996, -39137, -184], [174639, -316452, 34757, 10372, -2950, -15349, 10725, 759], [625322, -434069, 49339, 9519, -2587, -3402, 10378, -3801], [987622, -34790, -14906, 14384, -64, 13768, -13442, 3200], [-115578, 27940, -56284, 15190, 5242, 7744, 6714, 4750], [-24610, 102165, -63785, 10471, 937, 19132, -16454, -6933], [-537604, 42942, -19336, 2438, -5738, 1194, -14378, -7868], [158224, -310084, 18604, 24502, 4842, 7568, 5042, -3718], [1681594, -58014, -163961, -6038, -1740, -8113, -10311, -2065], [-3845860, -48823, -27815, 1483, 601, -4110, 4940, -3241], [-861172, -249917, -83270, 127, -5625, 10915, 27301, 8536], [263704, -169922, 67512, 8454, -4146, 386, -8658, 12888], [3042504, 157254, 4394, 11996, -5740, -4544, 18326, 6108], [-1255912, 124003, 1043, -1331, -2193, -9834, -6552, -5431], [-1265861, 203500, -106448, 8157, 6803, -236, 8937, 251], [-1192808, 454970, -169159, -4252, 1406, 7485, -1763, -10821], [4154335, 59475, -74286, 240, 2438, 16179, 2362, 2103], [1339602, 77503, 184441, -4937, 13473, 13608, 25244, -4781], [-2846574, -216858, -58314, -6166, 4374, 22812, 6736, 994], [1714561, -483420, -71499, -3771, -1295, -10613, -45262, -7214], [1158, -158594, -216733, -14434, 3080, 12075, 2109, -339], [4465983, -641, -62891, 7691, -7259, 2808, 8904, -2643], [3085383, 231632, 96297, -16916, -470, -34693, 29609, -10205], [-6578842, -406418, -73266, -8212, 9772, -24484, -19662, 656], [2313543, 518090, -97971, 10844, 10666, 13305, -39955, 1085], [277808, -148515, 13254, 24635, -4425, 2933, -65499, 474], [6491680, 320918, 67174, -19546, -4190, 3684, -19156, -1366], [-2016708, -464768, 159114, -38476, -4440, 24838, 11726, -13738], [3163880, 620323, 19477, -18121, -10879, 5788, 3876, 11197], [-351494, -344759, -14906, -35981, -865, 26953, 6173, -17666], [-3102046, -146107, -121420, -42357, -8541, -7145, -5805, -10868], [-1330926, 666553, -38453, 6369, -6897, -104, -39308, 18383], [-3863206, -763838, 113028, -25204, -19192, -19622, 48480, 20734], [1128639, 579046, -217483, 3332, 1114, 2357, 37197, 34145], [-5193730, -636614, -76532, 31342, -20698, 1618, 11746, -1588], [1134150, 347965, -108615, 7683, -13879, -8226, 81620, -4797], [-1154633, -96576, -137695, 30386, 1768, -16281, 51503, 5637], [-1992128, -158282, -31472, 2166, -12082, -26822, 78686, 2308], [433114, -224709, 26783, 11303, -27315, -16250, -16990, -7139], [-1106307, -444470, -157783, -26190, 20536, -11015, -36529, -17529], [7143636, -332500, 206872, -3148, 7380, 36868, 38964, -7628], [741565, -194551, 154964, -109142, -18068, -42745, 33430, 22803], [343251, 313477, 309193, 3759, 15385, 36050, 38728, -11261], [508056, 832158, -150960, 95170, 11922, -2662, -22886, -24432], [12038504, 624820, -139075, 20606, 8368, -22769, -111933, -18741], [5050652, -67499, 185851, 44861, 29547, -26208, 32956, -8483], [1734135, -432192, 125217, 46183, 10519, -22397, 44840, 8672], [-7854764, -104902, 186356, 27240, -4964, 36506, 32772, -14582], [2601048, -1090975, 42321, 22407, 15269, -12714, 43068, -20355], [5275646, 881653, -302120, 9669, 10161, -47829, 36729, 13114], [2433482, 971946, -66642, 20188, 36668, 18016, -32798, -30844], [-3152572, 586297, -31050, -31079, -23263, -7735, -13829, 59704], [-3292208, 916, -71742, -62620, -19872, -32678, 5062, 34442], [9077349, -910175, 180249, -15286, 7578, 61514, 60175, 4188], [-1880278, -2962150, -224628, 41680, 18420, 4858, -34140, 5786], [-8262391, 663022, 42893, -42245, 5847, 75657, 88336, -27918], [3711401, -537447, 306733, 9150, 3358, -15746, -40729, -14036], [-3810258, -1048409, 179289, -12577, -20167, -33248, 69700, 23627], [3576516, 573229, 64898, 34403, -34537, 33713, -99071, -28698], [1802406, -50675, 396411, -26747, 38171, 34580, 105048, -30129], [-7892186, -633088, 268660, -67044, 20284, -13548, -87064, 14500], [1797128, 679310, -348192, -31650, 5094, -51078, 4390, 26628], [-8803038, -1094473, -148394, 7021, 6801, 11827, -37137, -5126], [5079673, -1086436, 426769, 50093, 2625, -3713, -46458, -19542], [-909168, -896378, 105462, 113356, 20988, 130260, 12402, -48948], [-3641004, -567423, -48887, -9545, 8893, -43290, -185916, 14373], [2458818, 1098486, -181019, 96914, -25792, -82435, 40367, 35385], [-9031198, 2439021, 146315, 41285, 30451, 108804, 81928, -16929], [7070674, -100659, -8908, -83857, -22433, -5001, 88439, 16756], [-9429556, -2126996, -419870, 69134, -26098, -56206, -82696, 34780], [3862850, -2221190, -159708, -57296, 14276, -42342, -30324, -23810], [-5155195, 3139364, 217867, -37158, -64196, -49559, -15191, 21343], [-12577031, 71065, 130269, -165628, 3448, -28338, -229303, -16446], [-13357554, 1530517, -194747, -128663, -26253, -45414, -139522, 33865], [7621038, 2412687, 54722, 5943, -15873, 105487, 118309, -24036], [-12883173, 1738470, -268553, -3489, 15391, 60359, 174906, -4452], [6953527, 717854, 44551, -31074, -37056, 48287, -272167, 285], [9415517, -1403212, -155659, -27595, 22721, 50315, 106170, 44762], [20014068, -1345428, 589312, 95184, 1160, -53972, -62816, 17496], [-15790539, 1584312, -205317, -40896, -17166, -68119, -62073, -32955], [-624270, 4186524, -384740, -53086, -4274, -33384, -270890, -7970], [8993467, 1415777, -208044, -62899, 52541, -50813, 14753, 17056], [-15874140, -17823, -241622, -16293, -42793, -87963, -88351, 50058], [-2228234, -1884208, -227356, -29300, 18788, 65244, -8520, 41164], [-23087688, 2104805, 211312, 190389, 9465, -60597, -6679, 5374], [6129956, 1208244, -387778, 43416, -72044, 26702, -154522, -7830], [-361228, 4882301, 116577, -29413, 38097, 64838, 67732, 21659], [-2609442, 2249945, 27154, -112119, 13137, -140251, -146385, 83224], [-13416098, 2939176, -371878, 50438, 58958, 130446, 124880, 41148], [-3813470, 1685667, 35276, 69131, 34015, -142287, -15293, 14934], [-17291010, -806862, 202471, -65870, -84148, -73185, 202305, 37679], [-11190834, 1314625, 370111, 196449, -42681, 21132, -57576, 5459], [-6834589, 255528, -276212, 111825, -4241, 16076, -318815, -14361], [1813878, -2134360, 39750, -4502, -39590, -66294, -192344, -52872], [18563367, 190317, -922307, 174898, -44830, 76954, -155089, -21640], [-4488462, -568090, 228673, 19068, -34506, -74775, 37797, 78947], [9251438, 5964652, -85889, -138080, 31050, 51453, 77471, 9999], [-13454318, 5009060, 913838, -72562, 16462, -13130, 22796, -59840], [12582929, 4253407, -271279, -25447, -25061, -38992, 14450, 48967], [-11541738, -502944, 278502, -188694, 1266, -11502, -63392, -16008], [2617608, 1217760, 169368, -25660, 29052, 74464, 19964, -114036], [-7559034, -133378, -20686, 90672, 24720, -94168, 277874, -30328], [-10316014, 1840392, -110699, -112418, -1112, -101197, -135165, -12125], [21850500, 1370577, -880072, 5853, 79137, -11273, -122807, -5006], [-22773282, -835269, 304092, -160841, 51043, 63785, 148623, -62294], [-35434938, -1957860, 526954, 23638, -34034, 17226, 107712, 33040], [-20684472, 3546726, -517327, -106434, -62796, -166163, 109459, 112103], [14132614, 1631877, 1140721, -159183, -29317, -38130, -25662, -30291], [-14087382, -3992507, 146064, 33757, 111177, -91949, 215305, -30718], [10891622, 3987804, 193814, 15534, 45358, -47890, -262812, -54188], [2072618, 1258595, -412089, -61143, -44877, -94094, 208424, 145073], [-31090860, -982523, -366089, 40651, 42357, 121408, 30594, -62883], [-13160020, 365060, 712710, -118622, -53750, 5214, 289832, 65708], [-14059186, 5519520, 511692, 166972, -10212, 139212, 129280, -41604], [7800825, -2586886, 885025, 85235, 12047, -104423, 239508, 56762], [-5382696, 2795412, -393926, -285728, -6212, -75262, 137450, 134590], [-15998675, -418563, 891738, 73614, 6100, 121501, -415224, -45975], [-12710404, 1179014, 321498, 125058, -131426, -40136, 99012, -17010], [-2793073, -6261938, -36549, 75004, 75134, -78665, -350077, -81301], [874196, 4074542, 363728, 145570, 46242, 246482, 331866, 64576], [3869447, 3443630, -633265, 141970, 116996, -22457, -2003, -64643], [12635790, 5972674, 227884, -152208, 18468, 141746, 145652, -38214], [19037818, -1462929, -429292, 170583, 54571, 105141, 272535, -58498], [9556748, -3873325, 654459, -60795, -117801, -157794, 246488, -6807], [-29745331, 1967184, 152213, 6489, 44533, 199903, -97202, -61054], [-8683240, 489211, 691184, -276349, -79721, 4157, 228247, 86094], [-7100110, -2065189, -1094582, 265459, 54251, -44621, -230111, -60480], [437228, 494496, -1458938, 237418, -13422, -82758, -582696, -13016], [-1964446, 170953, 45268, 138921, -1179, -302949, -39903, -13990], [22849105, 7951376, 204753, -198616, -17242, -48637, -39051, 9299], [23186910, 4765816, 250098, -187244, -117160, 9110, -142194, 136890], [-17553589, 315033, 443416, -152171, 4297, -15601, 23073, -53758], [-19045951, -6257907, 960695, -139372, -49252, -34352, 141163, 146960], [-4348925, -5887436, -1394083, -109957, 26291, -338349, -485944, -25236], [26107013, -374189, 698714, 90039, -70653, 215363, -37391, -32330], [-46634834, 3097020, -763376, -28774, 115958, 182660, -19766, 81666], [3458198, -3706307, -178574, -27485, -13545, -231743, 104809, 12466], [6939912, -1795169, 292620, 109279, 57747, -232219, -658705, -196610], [9107714, -1192705, -549047, -172953, -87815, -117876, 173176, -20411], [12503302, 2037136, -80186, -8244, 94640, -114374, -193270, -69026], [18109334, 1979896, 1477918, 48002, 20954, -91694, -102624, -22664], [65527250, 772494, 402957, -37142, 64296, 27341, 75983, -71615], [-27205204, 385964, 1306830, 97916, -64920, 89742, -131934, 178874], [8263405, -528451, -814718, 188973, 32073, 416585, -182953, -66594], [-22778663, -1672573, -660505, 413622, -41026, 303178, 235333, -256], [14606082, -10200651, 1204737, 316323, 36177, -78674, 407644, 32547], [-4742671, -1398837, 368649, -170963, -40905, 167396, -167554, 47255], [117301, 5165199, -300424, -277190, 66232, -66151, -279870, -49221], [-62219257, 3233615, -144207, 67732, 135316, 261060, 35133, -162104], [-2503347, -11452810, -696549, 288347, 37939, 185395, -171714, 8704], [-18031816, 4156780, -288528, -173526, 96062, -13972, 645338, -75050], [-19173072, 4386480, -244086, -381270, -51774, -142098, -215308, 82968], [-1706949, -3285269, -634494, -55001, -129417, 105667, 783997, 119060], [20440289, -7106783, -79558, -6558, -41976, -250071, -591148, 199313], [49086869, 4027436, 754987, -251840, 8986, -59971, 130767, -70835], [11423401, 1055216, 243247, 141350, -40008, 196689, 361849, 219971], [-31496143, -6935550, -2511639, 415326, -31564, 74865, 21235, -11385], [-36599439, 9443595, -1116807, 147984, -15344, -295376, -509315, -97084], [2928908, 3491168, -314337, 121036, 123742, -296887, 70803, 106219], [60207207, -8605703, -1394677, -312785, -82819, 215180, -240214, -34007], [-47192233, 31622, -2432881, 169909, 23321, -187689, -266564, 103510], [-27812624, 120136, -1374014, -10226, -57050, -86090, -189480, -72632], [16915104, -1954870, 1921561, 203830, -72468, 88885, 531535, 178593], [-66025781, 273488, -1734245, 105636, 126678, 27649, 380483, -249555], [32378858, -3680734, -542475, 309450, 123232, -203123, -794157, -71093], [-11576420, -10132924, 783016, -553296, -32976, 98716, 191584, 75160], [-383426, -2395997, 371411, 144633, 188787, 352258, -906672, -3625], [7170443, -5703152, 695337, -65225, 59095, -559565, -326344, -5300], [3678680, 5636757, -2958829, 176119, 42025, 125288, -181346, -145277], [102012920, -7631312, -1120141, -489004, -165146, -211143, 334987, 164789], [-8658622, -5983715, 1465487, -24755, 78699, 66836, -215936, -211347], [13159472, 2784961, -1293121, 240273, 44895, 346652, 302088, 172219], [-16328999, 10132447, 364333, 46457, 80915, -275708, -148754, -231109], [-13320928, -8460100, -29708, 303920, 166640, 50480, 118004, -245584], [27759262, 9505088, 552986, -29306, -161570, 119886, 283544, -111432], [-28685680, -13516842, 1147656, 315174, 9486, 109242, -154322, -184240], [69017697, 3212353, 2552479, -484912, -125912, -97980, -17513, 39872], [51198904, -4655099, 849733, -184007, -74021, -317542, 218526, -27895], [12532676, -2427239, -1579513, 214577, -101129, -210656, -360900, -311159], [-14264554, -1233378, 2211269, 31210, 44792, -141403, -374537, -142711], [15726964, 2037657, -3550771, -143611, -14817, -421378, -196974, 88001], [48150910, -767622, -1105784, -415822, -121350, -266130, 338482, 289412], [-4606714, -2863550, -278500, 122506, -46854, -137390, 106294, 186740], [31980948, 2214275, 1913857, -165893, -192163, 167744, -682444, -176515], [34167095, 5682961, -1753348, -39558, -94580, -522701, -345234, 208981], [44444327, 366118, 1957403, -431661, -45741, 71427, -847774, 136932], [39570043, 2080493, -266509, 110987, -195079, -42632, 459366, 102125], [-8513696, 8024346, 482722, -756728, 98448, 136300, 580354, 53092], [5560436, 4981847, 1448367, -84985, -71363, 640630, 663254, -89425], [110413453, -7431089, -1227575, -228874, 7586, -68004, 391943, 162542], [25188026, -7184009, -558336, -134077, 33527, -325487, -1176633, -17830], [30870210, -3545496, 2868543, 536042, -93728, -108999, 121161, -111663], [-23357167, 2202246, -2098745, 480982, 98664, 595055, 95993, -139047], [-37389714, 5155119, -466038, -149023, -120971, -116345, -836409, 203986], [-25236530, 8335781, -825768, 78391, -168345, -461669, 516179, 189832], [10172172, -8767580, -301036, -334214, 221062, -114632, -55418, -558474], [63784002, -9450506, -483294, 577664, 177584, 626528, -260414, -239568], [-83881640, -6354397, -2498105, -56917, 100297, -127482, -530114, -12043], [40280064, 7561400, -2333828, 188792, 153200, -484668, -524532, -20688], [-7573734, 6898326, 491985, -715848, 66634, -58839, 541265, -127929], [-32986102, -1905870, 665151, -419166, 10740, -24837, -717651, 434689], [43514093, 14024169, 288986, 181633, -94427, -481459, -419533, -123266], [-81230033, -4855234, 1497936, 241534, -64938, 331378, -512266, -15564], [-54577933, 3013125, 514414, 344564, -39042, 556521, -1141062, 4507], [36439222, -7967137, -1436095, 705451, 41573, 126560, -613232, 61199], [5859495, 6527208, 4209741, -352349, 156651, -85865, -627920, 354020], [80106584, -569454, -1138390, 435462, 100090, 195556, 75992, 400442], [4734333, 10379694, -766651, -548142, -205192, 193769, 312779, 344215], [-18319785, -14647784, 2581395, 502187, 169511, -564319, 266158, -129254], [26876392, 4751009, -849053, 106631, -214239, 547368, 127034, -390135], [42300614, 841238, -3181843, -42404, -138786, 101869, 287521, 95911], [-69234626, 4405613, 527213, 119937, -79253, -522506, -243390, -371193], [-73343676, 14873916, -425731, -47148, 144642, 720175, -360119, -483883], [-8680022, -7803416, -1085086, 138486, 223454, 12046, -1276736, 62192], [-14581030, -3926789, -3244739, 688821, -333037, -394516, -1049886, -199249], [-128004611, -2998013, 2897516, -71790, 338064, -234751, 669790, 115323], [51823098, 14669252, 1109736, -330080, 215480, -332964, 294656, -153824], [44487073, -4834721, -1657538, -371432, -452018, 34055, 26838, 22673], [-85934657, 2962097, -2196847, -381554, 193190, 690434, 240911, -34468], [-60075044, 2953484, -1031236, -722128, -80504, -236696, -609476, 138776], [-25200980, -2677632, -1095780, 114930, -117706, 195340, -124866, -207386], [-14887674, 4095463, 2853902, -637733, 3995, 225155, 885965, -9344], [52816155, -1800330, 2027375, -99830, -313084, 812991, 83229, -388607], [24832521, -24631347, 1794711, 151059, -96743, -132244, -907734, -304371], [-182927631, 3228839, 2331280, -526889, -28993, -322719, 664327, 265368], [-833388, -5175605, -2107607, 139513, 398527, -6636, 1260350, 118121], [44862562, 15833792, 2259636, -170380, -403180, 260788, -114120, -36000], [-18104128, -157876, -1085704, -350918, 19286, 532212, -824926, 264098], [65488347, 25427272, 245513, -196249, -194873, -854613, -600448, 168300], [124064822, 6511493, -134292, 401123, -42821, -337457, 646795, -184620], [-21994598, 8877744, 2609428, 164768, 124616, -177932, -1567084, 74724], [131853764, 9452881, -3216332, 27665, -102051, -796461, 117889, 47782], [-10149665, -13168540, -336521, -352156, 43734, 711441, 59871, -15747], [34601302, -14902038, -2315278, -562884, -25692, -90916, 164398, -310936], [-17411247, -10821259, 867127, -292795, 186435, -524448, 717620, 155915], [11801482, 5383336, 4042710, -577602, 165078, 175650, 136012, 464528], [-39505537, 11167352, -891955, -711829, 82251, -309105, -80624, 500120], [82971464, -251918, 1051935, 801098, 505124, -14885, 115477, -21535], [-12466003, 977318, -3484723, -263347, 70613, 489625, -969162, 25872], [48213086, 3088778, -2479727, -202172, -295618, 1249717, 207997, 5991], [43807846, -83652, 942766, -322502, -645286, -987810, 596744, 379500], [-14554039, 1644997, 568322, 1269781, 294637, 504769, -114589, -521204], [-71036226, -13334003, -2863490, -398059, -394427, -94371, -981201, 213808], [-40350458, -23362741, 798568, -990719, 139225, 444245, 814837, 456152], [-152067602, -6619096, 2270316, 748332, 35420, -15412, 451088, -94300], [59237275, 11501471, -4347290, 1570290, 337524, 739255, -613368, -234685], [-29844224, 11482908, 1850911, -1148982, -572088, -138619, 336449, 218929], [-80617014, -1408294, -2415410, 644890, 276830, -518176, 105936, -283702], [-43693179, -2512905, 684865, 116494, 61418, 497044, 853223, -84406], [32038136, 6994571, -1047331, 393645, -113005, -157684, 279306, 578023], [-60658733, -4877112, -360248, 994565, -238989, 568112, -1137687, -158649], [-2315195, -4306114, 442811, 963926, 43096, -551381, -1634347, 101353], [184037266, 14833487, -4534020, -274049, -160965, 96301, -482689, -84582], [9588522, 2237672, -1636580, 217898, -209314, -1175108, 349518, -408454], [43639399, 15274537, -2676339, -166539, -262577, -850770, -828446, 330489], [-27587439, -3879316, -1328537, 270811, -415809, 415353, -944522, 423838], [146057963, -15590779, -2230665, 171471, -414371, -905068, -1309114, 214945], [-49090138, -9418253, 1517415, -464449, 442069, 325618, 722294, -418237], [205712902, -14820614, 1225884, 818300, 127464, 516514, -349920, -735086], [66386252, -24298406, 541345, -115276, -52218, -487483, 793637, 302059], [17793946, -17295204, 3708634, -282718, -58078, 991594, -815956, -66716], [-190637600, 21530250, 5995412, -585668, -60408, -203182, -384576, -216994], [14914171, -15738081, 3849723, 188901, -7957, -1239634, 241808, -280559], [-76494782, -2294053, -896820, 1555027, -187041, -1192511, 298499, 471378], [8994580, 1372490, 4855984, -779272, 299148, 231270, -1154408, 195498], [24683140, -24110640, -2462794, 189710, -224202, -805694, 178436, 906608], [-18997255, -5967530, 5455400, 277969, -212309, -37230, 264421, 134637], [100518035, -4820746, -1934881, -1763838, 148476, -78033, 1025965, 447957], [91819886, 23813726, 5666738, -394930, -361150, 75160, -179496, -14378], [169611857, -7458809, -2371429, -172738, -99002, -103318, 424937, -100700], [3364516, -1407368, 2006549, 196466, 731964, 1394771, -543441, -244077], [161376357, -783248, 2732865, -514783, 250781, 501515, 1668290, -407190], [-139732021, 20348044, 1589045, -64458, 212652, 627759, 985367, -319519], [75501282, 15417209, 4866247, 184715, 109133, 931020, 721106, 484689], [-98627951, -3420996, 2063387, -131851, 99837, 982421, 2526616, 376396], [-97420220, -10060907, 5271173, -1281661, -86335, -402858, 1410236, 125937], [107586430, 4987464, 1205579, 9538, 362632, 1302125, -889443, -343755], [92061799, -4312612, -3280577, 430543, -87045, -373543, 1355094, 774498], [-72153167, -2997487, -5417458, 242941, 372409, -387503, -1125917, 190030], [-65025542, -4966931, -2882553, -160971, -58197, -887544, -422556, -173461], [-19438984, 6684768, -1055788, 120632, -139888, -62788, -511332, -434292], [105332965, -20655522, 4549772, 38302, 227230, 959814, -706654, 7152], [-92503223, -21537368, 3957805, 62227, -170261, -206537, 2015804, 299552], [71297732, -30601662, -2890286, -486430, -173930, -934924, -2404, -585110], [-31517268, 4709731, 5199416, -651309, 180287, 744053, -991353, 385314], [166468100, 4854198, -3608792, -426386, 101166, -102030, -1677650, -173820], [46726080, 55811691, -315176, -389371, -147067, 193845, -306743, 154180], [4549766, -11681980, -5601564, -1398424, -132264, -587960, 38420, 380620], [-24075045, 11143276, 3217735, 65781, -683379, 465233, -619888, -296864], [-48805107, -4655252, -6502189, 461115, 434903, -270355, -1228158, -192294], [72112285, 27029267, -1021347, -503231, 471675, 975504, -520050, -493189], [-69896664, -17932670, 3166980, 658234, 631898, 2022986, 310614, -333456], [-2740250, 4260632, -7120240, 709508, -116156, -269672, -1645140, -492096], [316231324, 7079447, -552616, 1629487, 856907, 149769, -96581, 440670], [-39976378, 6752294, -3204724, 628708, 132632, 1480510, -654288, 587754], [167284580, -14903461, 2550162, -22043, 70201, 795347, 616347, 14626], [52921528, 17303480, -3853756, -758176, -809408, 975932, 1159420, 2216], [55246600, -5283306, -6938822, 157644, -440860, 1469496, 212190, 468812], [-103434903, 47415744, 3502539, -630913, -213653, -440319, -170306, 29194], [183466982, 17053100, 2583758, 1781038, -19498, 983822, 2032364, 136168], [-110187760, -39321328, 6907908, -302772, -297380, -8164, 869024, 249832], [-52370425, 22393173, -3888738, 583409, 139541, -1451107, -1049921, 370314], [-42932922, -21598782, 315153, 779492, 192766, -129635, -91075, -1187777], [84061053, -19320262, 6729425, 987904, 255790, 361949, 59501, 522665], [-26964523, -2301057, -5888560, 885402, -119944, -355727, -593446, -405861], [38786400, -20747596, 2985656, -103728, 865104, 306268, 1762072, -261860], [21682467, -21429324, 5273318, 939560, 462876, 934310, 513862, -1055002], [-224332824, 35831754, 2314362, 1115970, 268158, 70084, -1608020, 89650], [-222347837, -9971876, -4062779, 925320, 437182, 341707, -1424199, -90101], [-18420962, 10737431, 2294826, 579943, -298281, 719079, 965541, 368016], [114159588, 14525817, 5458065, -624185, 150885, 1252694, 1981324, -456435], [87675768, 24486589, 575740, -1864669, -789389, 198063, 2037891, 644200], [33825245, 43405517, 1609819, -1993496, -440656, -465916, -846285, 615540], [89838262, -15617990, 3256448, 847816, 76076, -282314, -1714056, -41298], [145589782, -15337835, -8974500, 110059, -370205, -317209, 2377003, 1080408], [-141492273, -7503823, -1825506, 541960, -15590, -76355, 2486622, -204149], [262234688, -20673479, -5918413, 643037, -130253, -196252, -1316092, -356871], [-226846354, 31954537, 6061397, 1060883, 220713, 1672982, 133232, -421773], [-53756796, 30541467, -3012192, -696661, -922601, -1412499, 642007, 74270], [-8481868, 8854201, -5589763, 1669667, 239025, -554306, -4236824, 68459], [203554081, 37779255, -3763736, 696636, -391834, -262523, -465260, 106807], [4483871, 22609814, 5096283, -1746809, 276631, -1073357, -2141498, -460712], [256890502, 15473205, -7215908, 597369, 28149, -207849, -225423, -123926], [60819598, -29431812, -1509338, -877626, -15010, -1342722, -1906332, -247868], [34395732, 24702075, 6783918, 90471, -15401, -827081, -1443791, 99700], [132222073, -19839518, -4625805, -1079170, 707112, -755241, 788749, -157247], [136955666, 28340363, -4255002, 2708121, 130237, 867431, 829931, 259390], [143490337, 30744893, -1450898, -401022, 113568, -1658967, 735088, -433943], [-28207539, 37491680, -6019909, 612992, -207942, -94079, 340239, -712287], [-193555899, -21037954, -8496120, 1419521, 731867, -1212166, -648275, 136221], [263336098, -18454819, -1974202, -286827, 170237, -2216891, 1758311, 275832], [31493186, 30187980, -10464780, 1071292, 85652, -2186568, -375264, 668604], [-56666572, -43793804, 1179302, 1324010, -400422, 297230, 541328, 38040], [-31228794, 47651515, 945196, -1436487, -438647, -153479, -811599, 89600], [166481996, -20107625, 6146093, -681219, 66963, 3015488, -116822, 101667], [-163659130, 7440588, 4488996, 900004, 1053332, -182616, -1386872, 1252], [35042618, -42586746, -9577454, 758270, -379518, -322080, -1543768, 437110], [58828938, 30425004, 4485847, 500322, 892568, -618675, -1848871, 5149], [61794259, 2809151, -822040, -849625, 242287, 629281, -379977, 1222044], [-182516208, 5498513, 748731, -837855, 612655, -823088, 4078052, -514065], [90479139, -44935055, 6109468, -328635, -470399, 215731, 1342389, -153834], [-188211388, -11207142, 1308276, -405056, 418556, -645686, -2956916, -441398], [-68320459, -37132886, -1507171, 286538, 978024, 1474069, -426685, -278049], [376372339, -32432454, -10171985, -847035, 3761, -867085, -1755868, -289158], [26974938, -29442583, -1299136, -2543669, 124531, 607607, 1666439, -226524], [-70305978, -24981698, 5425380, -711490, -305578, -1313082, 1291898, 715832]]
